###############################################################################
##
## Microsoft NGWS Debugger Test Shell (CORDBG) Makefile
##
###############################################################################

###############################################################################
##
## !!! EDIT THESE MACROS TO CORRECTLY LOCATE NGWS/WIN32 HEADERS/LIBS !!!
##
## NGWS_LIB_DIR, directory where NGWS libs live
## NGWS_INC_DIR, directory where NGWS headers live 
##
## WIN32_LIB_DIR, directory where Win32 libs live
## WIN32_INC_DIR, directory where Win32 headers live
## 
## E.G.
##
## WIN32_LIB_DIR= d:\progra~1\micros~1\vc98\lib
## WIN32_INC_DIR= d:\progra~1\micros~1\vc98\include
##
###############################################################################
NGWS_LIB_DIR= d:\progra~1\NGWSSDK\lib
NGWS_INC_DIR= d:\progra~1\NGWSSDK\include

WIN32_LIB_DIR= d:\progra~1\micros~1\vc98\lib
WIN32_INC_DIR= d:\progra~1\micros~1\vc98\include


###############################################################################
##
## General
##
###############################################################################
NULL=
SOURCE= .

OUTDIR= .\Debug
INTDIR= .\Debug
INCLUDE= .;$(NGWS_INC_DIR);$(WIN32_INC_DIR)


###############################################################################
##
## Tools (compiler, linker, etc)
##
###############################################################################
_LINKER= link.exe
_COMPILER= cl.exe


###############################################################################
##
## Win32 Related Libs
##
###############################################################################
WIN32_SDK_LIBS= \
    "$(WIN32_LIB_DIR)\uuid.lib"       \
    "$(WIN32_LIB_DIR)\ole32.lib"      \
    "$(WIN32_LIB_DIR)\libcpd.lib"     \
    "$(WIN32_LIB_DIR)\user32.lib"     \
    "$(WIN32_LIB_DIR)\rpcrt4.lib"     \
    "$(WIN32_LIB_DIR)\imagehlp.lib"   \
    "$(WIN32_LIB_DIR)\oleaut32.lib"   \
    "$(WIN32_LIB_DIR)\advapi32.lib"   \
    "$(WIN32_LIB_DIR)\kernel32.lib"   \
    "$(WIN32_LIB_DIR)\msvcrtd.lib"    


###############################################################################
##
## NGWS Related Libs
##
###############################################################################
NGWS_LIBS= \
    "$(NGWS_LIB_DIR)\corguids.lib"
    
    
###############################################################################
##
## Debugger Shell obj files
##
###############################################################################
OBJS= \
	"$(INTDIR)\shell.obj"        \
	"$(INTDIR)\source.obj"       \
	"$(INTDIR)\dshell.obj"       \
        "$(INTDIR)\cordbg.obj"       \
	"$(INTDIR)\commands.obj"     \
        "$(INTDIR)\debuggerutil.obj" 


###############################################################################
##
## MACROS
##
###############################################################################
_MACROS= \
    /D "_WIN32"                     \
    /D "_DEBUG"                     \
    /D "UNICODE"                    \
    /D "_UNICODE"                   \
    /D "_WIN32_DCOM"                \
    /D "WIN32_LEAN_AND_MEAN"        \
    /D "JIT_OR_NATIVE_SUPPORTED"    \
    /D "_META_DATA_SCOPE_WRAPPER_"                  


###############################################################################
##
## FLAGS
##
###############################################################################
_CFLAGS= \
   $(_MACROS) /Gz /nologo /MD /W2 /Gm /GX /Zi /Od \
   /Fp"$(INTDIR)\cordbg.pch" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 


_LFLAGS= \
    /nologo /subsystem:console /incremental:no /machine:I386 /nodefaultlib /out:"$(OUTDIR)\cordbg.exe"


###############################################################################
##
## Build Debugger Shell
##
###############################################################################
ALL: "$(OUTDIR)\cordbg.exe"


###############################################################################
##
## Output Directory
##
###############################################################################
"$(OUTDIR)":
    if not exist "$(OUTDIR)/$(NULL)" mkdir "$(OUTDIR)"


###############################################################################
##
## Rules
##
###############################################################################
.cpp{$(INTDIR)}.obj::
   $(_COMPILER) @<<
   $(_CFLAGS) $< 
<<

"$(OUTDIR)\cordbg.exe": "$(OUTDIR)" $(OBJS)
    $(_LINKER) @<<
  $(WIN32_SDK_LIBS) $(NGWS_LIBS) $(_LFLAGS) $(OBJS)
<<


###############################################################################
##
## Clean up
##
###############################################################################
CLEAN:
    -@erase "$(INTDIR)\vc60.idb"
    -@erase "$(INTDIR)\shell.obj"
    -@erase "$(INTDIR)\dshell.obj"
    -@erase "$(INTDIR)\cordbg.obj"
    -@erase "$(INTDIR)\source.obj"
    -@erase "$(OUTDIR)\cordbg.exe"
    -@erase "$(INTDIR)\commands.obj"
    -@erase "$(INTDIR)\debuggerutil.obj"


###############################################################################
##
## Debugger Shell Sources
##
###############################################################################
"$(INTDIR)\shell.obj":        $(SOURCE)\shell.cpp        "$(INTDIR)"
"$(INTDIR)\dshell.obj":       $(SOURCE)\dshell.cpp       "$(INTDIR)"
"$(INTDIR)\source.obj":       $(SOURCE)\source.cpp       "$(INTDIR)"
"$(INTDIR)\cordbg.obj":       $(SOURCE)\cordbg.cpp       "$(INTDIR)"
"$(INTDIR)\commands.obj":     $(SOURCE)\commands.cpp     "$(INTDIR)"
"$(INTDIR)\debuggerutil.obj": $(SOURCE)\debuggerutil.cpp "$(INTDIR)"

## End of File
